@@ -66,6 +66,7 @@ class Stylesheet(Serialisable):
         if numFmts is None:
             numFmts = NumberFormatList()
         self.numFmts = numFmts
+        self.number_formats = IndexedList()
         self.fonts = fonts
         self.fills = fills
         self.borders = borders
@@ -138,12 +139,6 @@ class Stylesheet(Serialisable):
             self.cellStyleXfs.xf.append(style.as_xf())
 
 
-    @property
-    def number_formats(self):
-        fmts = [n.formatCode for n in self.numFmts.numFmt]
-        return IndexedList(fmts)
-
-
     @property
     def custom_formats(self):
         return dict([(n.numFmtId, n.formatCode) for n in self.numFmts.numFmt])
@@ -158,7 +153,16 @@ class Stylesheet(Serialisable):
         for style in self.cell_styles:
             if style.numFmtId in custom:
                 fmt = custom[style.numFmtId]
-                style.numFmtId = formats.index(fmt) + 164
+                if fmt in BUILTIN_FORMATS_REVERSE: # remove builtins
+                    style.numFmtId = BUILTIN_FORMATS_REVERSE[fmt]
+                    continue
+                style.numFmtId = formats.add(fmt) + 164
+
+
+    def to_tree(self, tagname=None, idx=None, namespace=None):
+        tree = super(Stylesheet, self).to_tree(tagname, idx, namespace)
+        tree.set("xmlns", SHEET_MAIN_NS)
+        return tree
 
 
 def apply_stylesheet(archive, wb):
@@ -169,14 +173,10 @@ def apply_stylesheet(archive, wb):
         src = archive.read(ARC_STYLE)
     except KeyError:
         return wb
+
     node = fromstring(src)
     stylesheet = Stylesheet.from_tree(node)
 
-    wb._cell_styles = stylesheet.cell_styles
-    wb._named_styles = stylesheet.named_styles
-    for ns in wb._named_styles:
-        ns.bind(wb)
-
     wb._borders = IndexedList(stylesheet.borders)
     wb._fonts = IndexedList(stylesheet.fonts)
     wb._fills = IndexedList(stylesheet.fills)
@@ -184,6 +184,15 @@ def apply_stylesheet(archive, wb):
     wb._number_formats = stylesheet.number_formats
     wb._protections = stylesheet.protections
     wb._alignments = stylesheet.alignments
+    wb._table_styles = stylesheet.tableStyles
+
+    # need to overwrite openpyxl defaults in case workbook has different ones
+    wb._cell_styles = stylesheet.cell_styles
+    wb._named_styles = stylesheet.named_styles
+
+    for ns in wb._named_styles:
+        ns.bind(wb)
+
     if stylesheet.colors is not None:
         wb._colors = stylesheet.colors.index
 
@@ -216,8 +225,6 @@ def write_stylesheet(wb):
     stylesheet.cellXfs = CellStyleList(xf=xfs)
 
     stylesheet._split_named_styles(wb)
-    stylesheet.tableStyles = TableStyleList()
+    stylesheet.tableStyles = wb._table_styles
 
-    tree = stylesheet.to_tree()
-    tree.set("xmlns", SHEET_MAIN_NS)
-    return tree
+    return stylesheet.to_tree()
