@@ -1,5 +1,5 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 """Worksheet is the 2nd-level container in Excel."""
 
@@ -123,7 +123,8 @@ class Worksheet(_WorkbookChild):
         self._setup()
 
     def _setup(self):
-        self.row_dimensions = BoundDictionary("index", self._add_row)
+        self.row_dimensions = DimensionHolder(worksheet=self,
+                                              default_factory=self._add_row)
         self.column_dimensions = DimensionHolder(worksheet=self,
                                                  default_factory=self._add_column)
         self.page_breaks = PageBreak()
@@ -167,12 +168,12 @@ class Worksheet(_WorkbookChild):
 
     @property
     def selected_cell(self):
-        return self.sheet_view.selection.sqref
+        return self.sheet_view.selection[0].sqref
 
 
     @property
     def active_cell(self):
-        return self.sheet_view.selection.activeCell
+        return self.sheet_view.selection[0].activeCell
 
     @property
     def show_gridlines(self):
@@ -372,6 +373,12 @@ class Worksheet(_WorkbookChild):
         return self.iter_rows()
 
 
+    def __delitem__(self, key):
+        row, column = coordinate_to_tuple(key)
+        if (row, column) in self._cells:
+            del self._cells[(row, column)]
+
+
     @property
     def min_row(self):
         """The minimium row index containing data (1-based)
@@ -699,12 +706,19 @@ class Worksheet(_WorkbookChild):
         """ Set merge on a cell range.  Range is a cell range (e.g. A1:E1) """
 
         self.merged_cells.add(cr.coord)
+        self._clean_merge_range(cr)
+
+
+    def _clean_merge_range(self, cr):
+        """
+        Remove all but the top left-cell from a range of merged cells
+        """
 
         min_col, min_row, max_col, max_row = cr.bounds
         rows = range(min_row, max_row+1)
         cols = range(min_col, max_col+1)
         cells = product(rows, cols)
-        # all but the top-left cell are removed
+
         for c in islice(cells, 1, None):
             if c in self._cells:
                 del self._cells[c]
@@ -780,7 +794,14 @@ class Worksheet(_WorkbookChild):
         """
         Move either rows or columns around by the offset
         """
-        reverse = offset > 0 # start at the end if moving down
+        reverse = offset > 0 # start at the end if inserting
+
+        # need to make affected ranges contiguous
+        cells = self.iter_rows(min_row=min_row)
+
+        if row_or_col == 'col':
+            cells = self.iter_cols(min_col=min_col)
+        cells = list(cells)
 
         cells = sorted(self._cells.values(), key=attrgetter(row_or_col), reverse=reverse)
 
@@ -803,6 +824,7 @@ class Worksheet(_WorkbookChild):
         Insert row or rows before row==idx
         """
         self._move_cells(min_row=idx, offset=amount, row_or_col="row")
+        self._current_row = self.max_row
 
 
     def insert_cols(self, idx, amount=1):
@@ -816,15 +838,34 @@ class Worksheet(_WorkbookChild):
         """
         Delete row or rows from row==idx
         """
+
+        remainder = _gutter(idx, amount, self.max_row)
+
         self._move_cells(min_row=idx+amount, offset=-amount, row_or_col="row")
 
+        for row in remainder:
+            for col in range(self.min_column, self.max_column+1):
+                if (row, col) in self._cells:
+                    del self._cells[row, col]
+        self._current_row = self.max_row
+        if not self._cells:
+            self._current_row = 0
+
 
     def delete_cols(self, idx, amount=1):
         """
         Delete column or columns from col==idx
         """
+
+        remainder = _gutter(idx, amount, self.max_column)
+
         self._move_cells(min_col=idx+amount, offset=-amount, row_or_col="col_idx")
 
+        for col in remainder:
+            for row in range(self.min_row, self.max_row+1):
+                if (row, col) in self._cells:
+                    del self._cells[row, col]
+
 
     def _invalid_row(self, iterable):
         raise TypeError('Value must be a list, tuple, range or generator, or a dict. Supplied value is {0}'.format(
@@ -916,3 +957,13 @@ class Worksheet(_WorkbookChild):
             value = [value]
 
         self._print_area = [absolute_coordinate(v) for v in value]
+
+
+def _gutter(idx, offset, max_val):
+    """
+    When deleting rows and columns are deleted we rely on overwriting.
+    This may not be the case for a large offset on small set of cells:
+    range(cells_to_delete) > range(cell_to_be_moved)
+    """
+    gutter = range(max(max_val+1-offset, idx), min(idx+offset, max_val)+1)
+    return gutter
